@@ -247,7 +247,8 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 			AddBond (pBond);
 		}
 	}
-	if (m_Window)
+	m_Empty = !HasChildren ();
+ 	if (m_Window)
 		m_Window->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", HasChildren ());
 	return true;
 }
@@ -671,6 +672,7 @@ bool gcpDocument::Load (xmlNodePtr root)
 		node = node->next;
 	}
 	m_pView->Update (this);
+	m_Empty = !HasChildren ();
 	Update ();
 	m_bIsLoading = false;
 	if (m_Window)
@@ -978,6 +980,7 @@ void gcpDocument::OnUndo()
 	Update ();
 	EmptyTranslationTable ();
 	SetDirty (m_LastStackSize != m_UndoList.size () || (m_LastStackSize > 0 && m_OpID != m_UndoList.front ()->GetID ()));
+	m_Empty = !HasChildren ();
 }
 
 void gcpDocument::OnRedo()
@@ -998,6 +1001,7 @@ void gcpDocument::OnRedo()
 	m_bUndoRedo = false;
 	EmptyTranslationTable ();
 	SetDirty (m_LastStackSize != m_UndoList.size () || (m_LastStackSize > 0 && m_OpID != m_UndoList.front ()->GetID ()));
+	m_Empty = !HasChildren ();
 }
 
 void gcpDocument::FinishOperation()
@@ -1011,6 +1015,7 @@ void gcpDocument::FinishOperation()
 	}
 	m_pCurOp = NULL;
 	SetDirty (true);
+	m_Empty = !HasChildren ();
 	if (m_Window) {
 		m_Window->ActivateActionWidget ("/MainMenu/EditMenu/Undo", true);
 		m_Window->ActivateActionWidget ("/MainMenu/EditMenu/Redo", false);
